//
//  SCButtonSegment.swift
//  ButtonSegment
//
//  Created by tsc on 16/6/13.
//  Copyright © 2016年 tsc. All rights reserved.
//

import UIKit

@objc protocol SCButtonSegmentDelegate:NSObjectProtocol {
optional
    func buttonsDidClick(sender: UIButton);
}

class SCButtonSegment: UIStackView {
    
    var initialTag = 0
    var delegate :SCButtonSegmentDelegate!
    
    private var numberOfSegments = 0
    
    required init?(coder aDecoder: NSCoder) {
        super.init(coder: aDecoder)
        initial()
    }
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        initial()
    }

    func initial() {
        distribution = .FillEqually //均等分配
        alignment = .Leading  //从左布局
    }
    
    func insertSegmentWithTitle(title: String?,titleColor:UIColor, atIndex:NSInteger) {
        self.numberOfSegments += 1
        let button = createSegmentButton(title, titleColor: titleColor, atIndex: atIndex, NormalImg: nil, SelectedImg: nil)
        insertArrangedSubview(button, atIndex: atIndex)
    }
    
    func insertSegmentWithTitle(title: String? = "未知",titleColor:UIColor, normalImg:UIImage?,selectedImg:UIImage?,atIndex:NSInteger) {
        self.numberOfSegments += 1
        let button = createSegmentButton(title, titleColor: titleColor, atIndex: atIndex, NormalImg: normalImg, SelectedImg: selectedImg)
        insertArrangedSubview(button, atIndex: atIndex)
    }
    
    func createSegmentButton(title: String? = "未知",titleColor: UIColor? = UIColor.blackColor() ,atIndex: NSInteger = 0,NormalImg:UIImage? = nil,SelectedImg:UIImage? = nil) -> UIButton {
        
        var button:UIButton?
        
        button = UIButton(type: .Custom) // 一定有值 ，返回时可以强制解析
        
        button?.tag = initialTag + numberOfSegments - 1
        
        button?.setTitle(title, forState: .Normal)
        
        button?.setTitleColor(titleColor, forState: .Normal)
        
        button?.setBackgroundImage(NormalImg, forState: .Normal)
        
        button?.setBackgroundImage(SelectedImg, forState: .Highlighted)
        
        button?.setBackgroundImage(SelectedImg, forState: .Selected)
        
        button?.addTarget(self, action: #selector(buttonDidClick(_:)) ,forControlEvents: .TouchUpInside)
        
        return button!
    }
    
    func buttonDidClick(sender:UIButton){

        if self.delegate != nil && self.delegate.respondsToSelector(#selector(self.delegate.buttonsDidClick(_:))){
            self.delegate.buttonsDidClick!(sender)
        }

    }
    
}
